# nvm-run
Just *run* a particular version of node using nvm. Handles all the scripting stuff.

AI-generated code.

## Installation
```
pipx nstall nvm-run
```

## Usage 
You have to install the version yourself with:
```
nvm-run --isntall 18
```

You can then a particular version of claude with
```
nvm-run 18 -- program args
```

# About
I make tools for reading and reasearchw ith and without AI. You can find me on X at @readwithai
